@@ -6,7 +6,6 @@ import logging
 import os
 import shutil
 import sys
-import urllib.request
 from collections.abc import Iterable
 from importlib import import_module
 from types import ModuleType
@@ -130,10 +129,21 @@ def _import_module(name: str, file_dir: str | None = None) -> ModuleType:
 def _download_module(url: str) -> ModuleType:
     logger.info("Downloading preload at %s", url)
     assert is_webaddress(url)
+    # This is the only place where urrllib3 is used and it is a relatively heavy
+    # import. Do lazy import to reduce import time
+    import urllib3
 
-    request = urllib.request.Request(url, method="GET")
-    response = urllib.request.urlopen(request)
-    source = response.read().decode()
+    with urllib3.PoolManager() as http:
+        response = http.request(
+            method="GET",
+            url=url,
+            retries=urllib3.util.Retry(
+                status_forcelist=[429, 504, 503, 502],
+                backoff_factor=0.2,
+            ),
+        )
+
+        source = response.data
 
     compiled = compile(source, url, "exec")
     module = ModuleType(url)
@@ -175,6 +185,8 @@ class Preload:
         self.argv = list(argv)
         self.file_dir = file_dir
 
+        logger.info("Creating preload: %s", self.name)
+
         if is_webaddress(name):
             self.module = _download_module(name)
         else:
@@ -185,6 +197,7 @@ class Preload:
         dask_setup = getattr(self.module, "dask_setup", None)
 
         if dask_setup:
+            logger.info("Run preload setup: %s", self.name)
             if isinstance(dask_setup, click.Command):
                 context = dask_setup.make_context(
                     "dask_setup", self.argv, allow_extra_args=False
@@ -194,17 +207,16 @@ class Preload:
                 )
                 if inspect.isawaitable(result):
                     await result
-                logger.info("Run preload setup click command: %s", self.name)
             else:
                 future = dask_setup(self.dask_object)
                 if inspect.isawaitable(future):
                     await future
-                logger.info("Run preload setup function: %s", self.name)
 
     async def teardown(self):
         """Run when the server starts its close method"""
         dask_teardown = getattr(self.module, "dask_teardown", None)
         if dask_teardown:
+            logger.info("Run preload teardown: %s", self.name)
             future = dask_teardown(self.dask_object)
             if inspect.isawaitable(future):
                 await future
